from prettyqt.qt import QtMultimedia


class MediaBindableInterface(QtMultimedia.QMediaBindableInterface):
    pass
